# Copyright 1999-2010 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

EAPI=2
NEED_PYTHON=2.4

inherit distutils bash-completion elisp-common eutils versionator

LANGS="en es ru"

MY_RV=${PV/_/}
MY_PV=${MY_RV/beta/b}
LPV="${MY_PV}"
MY_P="${PN}-${MY_PV}"
SERIES=$(get_version_component_range 1-2)
S=${WORKDIR}/${MY_P}

DESCRIPTION="Bazaar is a next generation distributed version control system."
HOMEPAGE="http://bazaar-vcs.org/"
SRC_URI="http://launchpad.net/bzr/${SERIES}/${LPV}/+download/${MY_P}.tar.gz"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="~amd64 ~ia64 ~ppc ~sparc ~x86 ~x86-fbsd"
IUSE="curl doc emacs html kerberos +sftp test"

for X in ${LANGS}; do
	IUSE="${IUSE} linguas_${X}"
done

python_rdep="|| ( >=dev-lang/python-2.5 dev-python/celementtree )
	sftp? ( >=dev-python/paramiko-1.5 )
	curl? ( dev-python/pycurl )
	kerberos? ( dev-python/pykerberos )
	sys-libs/zlib"
test_dep=">=dev-python/testtools-0.9.2"
DEPEND="dev-python/pyrex
	!=dev-python/pyrex-0.9.6.3
	doc? ( html? ( dev-python/sphinx ) )
	emacs? ( virtual/emacs )
	test? (
		${python_rdep}
		${test_dep}
		|| ( dev-python/pyftpdlib dev-python/medusa )
	)"
RDEPEND="${python_rdep}
	test? ( ${test_dep} )"

PYTHON_MODNAME="bzrlib"
SITEFILE=71${PN}-gentoo.el

DOCS="README NEWS doc/*.txt"

src_prepare() {
	# Don't run lock permission tests when running as root
	epatch "${FILESDIR}"/${PN}-0.90-tests-fix_root.patch
	# Fix permission errors when run under directories with setgid set.
	epatch "${FILESDIR}"/${PN}-0.90-tests-sgid.patch
	# Only build the docs in languages that the user specifies.
	sed -i -e '/cd doc\/.* && make html/d' Makefile
}

src_compile() {
	distutils_src_compile
	if use emacs; then
		elisp-compile contrib/emacs/bzr-mode.el || die
	fi
	if use doc && use html; then
		emake html-sphinx
		emake -C doc/developers html
		${python} tools/package_docs.py doc/developers build_doc
		local lang
		for lang in ${LANGS}; do
			if use linguas_${lang}; then
				emake -C doc/${lang} html
				${python} tools/package_docs.py doc/${lang} build_doc
			fi
		done
	fi
}

src_install() {
	distutils_src_install --install-data /usr/share
	if use doc; then
		docinto developers
		dodoc doc/developers/*.{dot,txt}
		local lang
		for lang in ${LANGS}; do
			if ! use linguas_${lang}; then
				continue
			fi
			local dir
			for dir in `ls doc/${lang}/`; do
				if test -n "`ls doc/${lang}/${dir}`"; then
					if test "${dir}" != "${dir#_}"; then
						continue
					fi
					docinto ${lang}/"${dir}"
					local f
					for f in `ls doc/${lang}/"${dir}"`; do
						if test -d doc/${lang}/"${dir}/${f}"; then
							docinto ${lang}/"${dir}/${f}"
							dodoc doc/${lang}/"${dir}/${f}"/*
							docinto ${lang}/"${dir}"
						elif test "${f}" != "${f%.txt}"; then
							if test -e "${f}"; then
								dodoc "${f}"
							else
								dodoc doc/${lang}/"${dir}/${f}"
							fi
						fi
					done
				fi
			done
		done
		if use html; then
			rm -rf build_doc/downloads
			local dir
			for dir in `ls build_doc/`; do
				docinto html/${dir}
				local f
				for f in `ls build_doc/${dir}/`; do
					if test "${dir}" != "developers"; then
						einfo "f = ${f}"
					fi
					if test -d "build_doc/${dir}/${f}" -a "${f}" = "${f#_sources}"; then
						docinto html/${dir}/${f}
						dohtml build_doc/${dir}/${f}/*
						docinto html/${dir}
					elif test "${f}" != "${f%.html}" -o "${f}" != "${f%.js}"; then
						dohtml build_doc/${dir}/${f}
					fi
				done
			done
		fi
	fi
	if use emacs; then
		elisp-install ${PN} contrib/emacs/*.el* || die
		elisp-site-file-install "${FILESDIR}/${SITEFILE}" || die
		# don't add automatically to the load-path, so the sitefile
		# can do a conditional loading
		touch "${D}${SITELISP}/${PN}/.nosearch"
	fi
	insinto /usr/share/zsh/site-functions
	doins contrib/zsh/_bzr
	dobashcompletion contrib/bash/bzr.simple bzr
}

pkg_postinst() {
	distutils_pkg_postinst
	bash-completion_pkg_postinst
	if use emacs; then
		elisp-site-regen
		elog "If you are using a GNU Emacs version greater than 22.1, bzr support"
		elog "is already included.  This ebuild does not automatically activate bzr support"
		elog "in versions below, but prepares it in a way you can load it from your ~/.emacs"
		elog "file by adding"
		elog "       (load \"bzr-mode\")"
	fi
}

pkg_postrm() {
	distutils_pkg_postrm
	use emacs && elisp-site-regen
}

src_test() {
	PYTHONPATH="build/lib*" "${python}" "${S}"/bzr --no-plugins selftest \
		|| die
}
